# gneiss changelog

## Version 0.1.3

### Features
* Added write and read io for RegressionResults object [#72](https://github.com/biocore/gneiss/issues/72)

## Version 0.1.2

### Features
* Added `ladderize` and `gradient_sort` [#29](https://github.com/biocore/gneiss/issues/29)

### Bug fixes


## Version 0.0.2

### Features
* Added statsmodels inference [#22](https://github.com/biocore/gneiss/pull/22)
* Added support for ordinary least squares regression [#33](https://github.com/biocore/gneiss/pull/33)
* Added support for linear mixed effects models [#38](https://github.com/biocore/gneiss/pull/38)
* Added RegressionResults object to summarize statistics from statistical analyses
* Adding in a niche sorting algorithm `gneiss.sort.niche_sort` that can generate a band table given a gradient [#16](https://github.com/biocore/gneiss/pull/16)
* Adding in utility functions for handing feature tables, metadata, and trees. [#12](https://github.com/biocore/gneiss/pull/12)
* Adding GPL license.

### Bug fixes
